@@ -171,10 +171,10 @@ the app state with the suffix `_save`, so e.g. for the app state `flow_id` the e
 the event method returns a value that is not `None` then this value will be stored/saved.
 
 The third event gets fired on app startup when the app got upgraded to a higher version of the app state variable
-APP_STATE_VERSION_VAR_NAME (`app_state_version`). It will be called providing the version number for each version that
-is higher than the version of the previously installed main config file, until the version of the bundled/new-installed
-main config file get reached. So if e.g. the previously installed app state version was 3 and the new version number is
-6 then this event will be fired 3 times with the argument 4, 5 and 6. It can be used e.g. to change or add app state
+APP_STATE_VERSION_VAR_NAME (`app_state_version`). It will be called providing the version number for each version to
+upgrade, starting with the version of the previously installed main config file, until the upgrade version of the main
+config file get reached. So if e.g. the previously installed app state version was 3 and the new version number is
+6 then this event will be fired 3 times with the argument 3, 4 and 5. It can be used e.g. to change or add app state
 variables or for to adapt the app environment.
 
 
@@ -378,18 +378,18 @@ from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type
 
 from ae.base import (                                                                                   # type: ignore
-    NAME_PARTS_SEP, UNSET, duplicates, instantiate_config_parser, now_str, snake_to_camel)
+    CFG_EXT, INI_EXT, NAME_PARTS_SEP, UNSET, duplicates, instantiate_config_parser, now_str, snake_to_camel)
 from ae.files import RegisteredFile                                                                     # type: ignore
 from ae.paths import (                                                                                  # type: ignore
-    add_common_storage_paths, copy_file, copy_tree, norm_path, path_folders, Collector, FilesRegister)
+    add_common_storage_paths, copy_file, copy_tree, norm_path, path_folders, Collector, FilesRegister, placeholder_key)
 from ae.updater import MOVES_SRC_FOLDER_NAME, check_all                                                 # type: ignore
 from ae.inspector import stack_var                                                                      # type: ignore
 from ae.i18n import default_language, load_language_texts, register_translations_path                   # type: ignore
 from ae.core import DEBUG_LEVELS, registered_app_names                                                  # type: ignore
-from ae.console import ConsoleApp, INI_EXT  # type: ignore
+from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.1.64'
+__version__ = '0.1.65'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -690,7 +690,7 @@ class MainAppBase(ConsoleApp, ABC):
         """ backup config files and image/sound/translations resources to {ado}<now_str>.
 
         config files are collected from from {ado}, {usr} or {cwd} (the first found file name only - see/sync-with
-        :meth:`ae.console.ConsoleApp.add_cfg_files).
+        :meth:`ae.console.ConsoleApp.add_cfg_files`).
 
         resources are copied from {ado} or {cwd} (only the first found resources root path).
         """
@@ -698,15 +698,15 @@ class MainAppBase(ConsoleApp, ABC):
         os.makedirs(backup_root)
 
         coll = Collector()
-        app_configs = tuple(ana + "." + ext for ana in registered_app_names() for ext in ('ini', 'cfg'))
-        coll.collect("{ado}", "{usr}", "{cwd}", append=app_configs, only_first_of='prefix')
+        app_configs = tuple(ana + ext for ana in registered_app_names() for ext in (INI_EXT, CFG_EXT))
+        coll.collect("{ado}", "{usr}", "{cwd}", append=app_configs, only_first_of=())
         for file in coll.files:
-            copy_file(file, os.path.join(backup_root, os.path.basename(file)))
+            copy_file(file, os.path.join(backup_root, placeholder_key(file) + "_" + os.path.basename(file)))
 
         coll = Collector(path_scanner=path_folders)
-        coll.collect("{ado}", "{cwd}", append=('img', 'loc', 'snd'), only_first_of='prefix')
+        coll.collect("{ado}", "{cwd}", append=('img', 'loc', 'snd'), only_first_of=())
         for path in coll.paths:
-            copy_tree(path, os.path.join(backup_root, os.path.basename(path)))
+            copy_tree(path, os.path.join(backup_root, placeholder_key(path) + "_" + os.path.basename(path)))
 
         return backup_root
 
@@ -867,16 +867,6 @@ class MainAppBase(ConsoleApp, ABC):
         """
         return stack_var(class_name)
 
-    def bundled_config_app_state_version(self) -> int:
-        """ determine app state version from bundled config file (if not already moved).
-
-        :return: value of app state variable APP_STATE_VERSION_VAR_NAME or 0 if config file got moved on first app run.
-        """
-        cfg_file_name = os.path.join(MOVES_SRC_FOLDER_NAME, self.app_name + INI_EXT)
-        cfg_parser = instantiate_config_parser()
-        cfg_parser.read(cfg_file_name, encoding='utf-8')
-        return cfg_parser.getint(APP_STATE_SECTION_NAME, APP_STATE_VERSION_VAR_NAME, fallback=0)
-
     @staticmethod
     def dpi_factor() -> float:
         """ dpi scaling factor - overwrite if the used GUI framework supports dpi scaling. """
@@ -1236,11 +1226,11 @@ class MainAppBase(ConsoleApp, ABC):
                 self._last_focus_flow_id = val
 
         current_version = app_states.get(APP_STATE_VERSION_VAR_NAME, 0)
-        bundled_version = self.bundled_config_app_state_version()
-        if bundled_version > current_version:
-            for version in range(current_version, bundled_version + 1):
-                self.call_method('on_app_state_version_upgrade', version)
-            self.change_app_state(APP_STATE_VERSION_VAR_NAME, bundled_version, send_event=False, old_name=UNSET)
+        upgrade_version = self.upgraded_config_app_state_version()
+        if upgrade_version > current_version:
+            for from_version in range(current_version, upgrade_version):
+                self.call_method('on_app_state_version_upgrade', from_version)
+            self.change_app_state(APP_STATE_VERSION_VAR_NAME, upgrade_version, send_event=False, old_name=UNSET)
 
     def show_popup(self, popup_class: Type, **popup_kwargs) -> Any:
         """ open Popup or DropDown by calling `show` method of passed instance.
@@ -1275,6 +1265,17 @@ class MainAppBase(ConsoleApp, ABC):
         if self._stop_event_loop:
             self._stop_event_loop()         # will exit the self._start_event_loop() method called by self.run_app()
 
+    def upgraded_config_app_state_version(self) -> int:
+        """ determine app state version of an app upgrade.
+
+        :return:                value of app state variable APP_STATE_VERSION_VAR_NAME if the app got upgraded (and has
+                                a config file from a previous app installation), else 0.
+        """
+        cfg_file_name = os.path.join(MOVES_SRC_FOLDER_NAME, self.app_name + INI_EXT)
+        cfg_parser = instantiate_config_parser()
+        cfg_parser.read(cfg_file_name, encoding='utf-8')
+        return cfg_parser.getint(APP_STATE_SECTION_NAME, APP_STATE_VERSION_VAR_NAME, fallback=0)
+
     def widget_by_attribute(self, att_name: str, att_value: str) -> Optional[Any]:
         """ determine the widget referenced by the passed attribute name and value.
 
